summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2020-05-12 16:54:54 +0200
committerCarl Hetherington <cth@carlh.net>2020-05-12 16:54:54 +0200
commitc6475f24a7b21fe2291ebc809431ecc2654d3355 (patch)
tree20669816386ba0cd28d1cef2c4c7836cb47098f5 /src/lib
parent21606f2f5781f648c5dd26020983e4fdaec4fd19 (diff)
Fix test failures with new verification note in libdcp.scaling-rework
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/dcp.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/dcp.cc b/src/lib/dcp.cc
index c62b339fa..477b61e9f 100644
--- a/src/lib/dcp.cc
+++ b/src/lib/dcp.cc
@@ -75,9 +75,9 @@ DCP::cpls () const
list<dcp::VerificationNote> notes;
dcp->read (&notes, true);
if (!_tolerant) {
/** We accept and ignore EmptyAssetPathError but everything else is bad */
BOOST_FOREACH (dcp::VerificationNote j, notes) {
- if (j.code() == dcp::VerificationNote::EMPTY_ASSET_PATH) {
+ if (j.code() == dcp::VerificationNote::EMPTY_ASSET_PATH || j.code() == dcp::VerificationNote::EXTERNAL_ASSET) {
LOG_WARNING("Empty path in ASSETMAP of %1", i.string());
} else {
boost::throw_exception(dcp::ReadError(dcp::note_to_string(j)));
@@ -75,9 +75,9 @@ DCP::cpls () const
dcp->read (&notes, true);
if (!_tolerant) {
- /** We accept and ignore EmptyAssetPathError but everything else is bad */
+ /** We accept and ignore EMPTY_ASSET_PATH and EXTERNAL_ASSET but everything else is bad */
BOOST_FOREACH (dcp::VerificationNote j, notes) {